@@ -1,7 +1,7 @@
 package Data::Sah::Coerce::perl::date::str_alami;
 
-our $DATE = '2016-05-20'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $DATE = '2016-05-22'; # DATE
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict;
@@ -9,9 +9,11 @@ use warnings;
 
 sub meta {
     +{
+        v => 2,
         enable_by_default => 0,
         might_die => 1,
         prio => 60, # a bit lower than normal
+        precludes => [qr/\Astr_alami(_.+)?\z/],
     };
 }
 
@@ -49,7 +51,7 @@ Data::Sah::Coerce::perl::date::str_alami - Coerce date from string parsed by Dat
 
 =head1 VERSION
 
-This document describes version 0.002 of Data::Sah::Coerce::perl::date::str_alami (from Perl distribution Data-Sah-Coerce-perl-date-str_alami), released on 2016-05-20.
+This document describes version 0.003 of Data::Sah::Coerce::perl::date::str_alami (from Perl distribution Data-Sah-Coerce-perl-date-str_alami), released on 2016-05-22.
 
 =head1 DESCRIPTION
 
